<?php
/*
Plugin Name:  Force Password Change
Description:  Require users to change their password on first login.
Version:      0.3
License:      GPL v2 or later
Plugin URI:   https://github.com/lumpysimon/wp-force-password-change
Author:       Simon Blackbourn @ Lumpy Lemon
Author URI:   https://twitter.com/lumpysimon
Author Email: simon@lumpylemon.co.uk
Text Domain:  force_password_change
Domain Path:  /languages/
*/



class forcePasswordChange {
	// just a bunch of functions called from various hooks
	function __construct() {
		add_action( 'user_register',           array( $this, 'registered' ) );
		add_action( 'personal_options_update', array( $this, 'updated' ) );
		add_action( 'template_redirect',       array( $this, 'redirect' ) );
		add_action( 'current_screen',          array( $this, 'redirect' ) );
		add_action( 'admin_notices',           array( $this, 'notice' ) );
	}
	
	// add a user meta field when a new user is registered
	function registered( $user_id ) {
		add_user_meta( $user_id, 'force-password-change', 1 );
	}

	// delete the user meta field when a user successfully changes their password
	function updated( $user_id ) {
		$pass1 = $pass2 = '';
		if ( isset( $_POST['pass1'] ) )
			$pass1 = $_POST['pass1'];
		if ( isset( $_POST['pass2'] ) )
			$pass2 = $_POST['pass2'];
		if (
			$pass1 != $pass2
			or
			empty( $pass1 )
			or
			empty( $pass2 )
			or
			false !== strpos( stripslashes( $pass1 ), "\\" )
			)
			return;
			delete_user_meta( $user_id, 'force-password-change' );
	}

	function redirect() {
		global $current_user;
		if ( is_admin() ) {
			$screen = get_current_screen();
			if ( 'profile' == $screen->base )
				return;
		}
		if ( ! is_user_logged_in() )
			return;
		if ( current_user_can( 'activate_plugins' ) )
			return;
		wp_get_current_user();
		if ( get_user_meta( $current_user->ID, 'force-password-change', true ) ) {
			wp_redirect( admin_url( 'profile.php' ) );
			exit;
		}
	}

	// if the user meta field is present, display an admin notice
	function notice() {
		global $current_user;
		wp_get_current_user();
		if ( get_user_meta( $current_user->ID, 'force-password-change', true ) ) {
			printf(
				'<div class="error"><p>%s</p></div>',
				__( 'Please change your password in order to continue using this website', 'force_password_change' )
				);
		}
	}
}
$force_password_change = new forcePasswordChange;
?>